<?php

declare(strict_types=1);

namespace App\Services\WorkingDays\PublicHolidays\Storage;

use App\Models\NonWorkingDays;

/**
 * Interface for storing and retrieving public holidays independent on country.
 */
interface PublicHolidaysStorageInterface
{
    /**
     * Determine if a given public holiday is in a given country.
     * @param string $countryCode
     * @param \DateTimeImmutable $holidayDate
     * @return bool
     */
    public function isPublicHoliday(string $countryCode, \DateTimeImmutable $holidayDate): bool;

    /**
     * Returns all public holidays in a given country within a given interval.
     * @param string $countryCode
     * @param \DateTimeImmutable $startDate
     * @param \DateTimeImmutable $endDate
     * @return NonWorkingDays[]
     */
    public function getPublicHolidaysInInterval(string $countryCode, \DateTimeImmutable $startDate, \DateTimeImmutable $endDate): array;

    /**
     * Counts all public holidays in a given country within a given interval.
     * @param string $countryCode
     * @param \DateTimeImmutable $startDate
     * @param \DateTimeImmutable $endDate
     * @return int
     */
    public function countPublicHolidaysInInterval(string $countryCode, \DateTimeImmutable $startDate, \DateTimeImmutable $endDate): int;

    /**
     * Stores a public holiday in the storage.
     * @param string $countryCode
     * @param \DateTimeImmutable $holidayDate
     * @return NonWorkingDays|null
     */
    public function storePublicHoliday(string $countryCode, \DateTimeImmutable $holidayDate): ?NonWorkingDays;
}
